Module command

Module command 

Gate command for policy-based spec validation

This module provides gate command implementation for evaluating specs against configurable policies to determine if they meet requirements for CI/CD gates.

Structs

GateCommand
Gate command for policy-based spec validation