SpecDataProvider

Trait SpecDataProvider 

pub trait SpecDataProvider {
    // Required methods
    fn base_path(&self) -> &Path;
    fn spec_id(&self) -> &str;
    fn receipt_manager(&self) -> &ReceiptManager;
    fn phase_completed(&self, phase: PhaseId) -> bool;
    fn pending_fixups_result(&self) -> PendingFixupsResult;
}
Trait for types that can provide spec data for gate evaluation

This trait abstracts data sources needed for gate checks, allowing gate evaluation to work with different data providers (e.g., OrchestratorHandle, direct file system access, etc.).

Required Methods

fn base_path(&self) -> &Path

Get the base path for the spec

fn spec_id(&self) -> &str

Get the spec ID

fn receipt_manager(&self) -> &ReceiptManager

Get the receipt manager

fn phase_completed(&self, phase: PhaseId) -> bool

Check if a phase is completed

fn pending_fixups_result(&self) -> PendingFixupsResult

Get the pending fixups result

Implementors