pub trait SpecDataProvider {
// Required methods
fn base_path(&self) -> &Path;
fn spec_id(&self) -> &str;
fn receipt_manager(&self) -> &ReceiptManager;
fn phase_completed(&self, phase: PhaseId) -> bool;
fn pending_fixups_result(&self) -> PendingFixupsResult;
}Expand description
Trait for types that can provide spec data for gate evaluation
This trait abstracts data sources needed for gate checks, allowing gate evaluation to work with different data providers (e.g., OrchestratorHandle, direct file system access, etc.).
Required Methods
Sourcefn receipt_manager(&self) -> &ReceiptManager
fn receipt_manager(&self) -> &ReceiptManager
Get the receipt manager
Sourcefn phase_completed(&self, phase: PhaseId) -> bool
fn phase_completed(&self, phase: PhaseId) -> bool
Check if a phase is completed
Sourcefn pending_fixups_result(&self) -> PendingFixupsResult
fn pending_fixups_result(&self) -> PendingFixupsResult
Get the pending fixups result